package jp.agentec.sinaburocast.common;

import java.io.File;
import java.io.IOException;
import java.io.Serializable;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpSessionBindingEvent;
import javax.servlet.http.HttpSessionBindingListener;

import jp.agentec.sinaburocast.common.io.FileUtil;
import jp.agentec.sinaburocast.vo.AuthenticatedTokenVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.log4j.Logger;

public class SessionBindingListener implements HttpSessionBindingListener, Serializable {
    private static final long serialVersionUID = 1781233323956479423L;

    protected final Log authLogger = LogFactory.getLog("AUTH");
	private static final Logger logger = Logger.getLogger(SessionBindingListener.class);
	private final AuthenticatedTokenVO token;

	@SuppressWarnings("unused")
	private transient final ServletContext context;
	private String cause = "session invalidation or timeout";
	private String workPath;
	private boolean appDl = false;

	/**
	 * コンストラクタ
	 *
	 * @param authenticatedToken
	 * @param context
	 */
	public SessionBindingListener(AuthenticatedTokenVO authenticatedToken, ServletContext context) {
		super();
		this.token = authenticatedToken;
		this.context = context;
	}

	public SessionBindingListener(AuthenticatedTokenVO authenticatedToken, ServletContext context, boolean appDl) {
		super();
		this.token = authenticatedToken;
		this.context = context;
		this.appDl = appDl;
	}

	/**
	 * セッション終了の原因としてログアウトをセットする。
	 */
	public void setCauseAsLogout() {
		cause = "user logout";
	}

	/**
	 * セッションに紐付いたアップロード用の一時ディレクトリををセットする。
	 */
	public void setWorkPath(String workPath) {
		this.workPath = workPath;
	}


	/**
	 * セッション投入時に呼び出される。
	 */
	public void valueBound(HttpSessionBindingEvent event) {
		String msg = "[LOGIN] loginId:" + token.loginId + " userId:" + token.userId + " userName:" + token.userName + " userType:" + token.userType + " sessionid:" + event.getSession().getId();
			authLogger.info(msg);
	}

	/**
	 * セッションからの削除時に呼び出される
	 */
	public void valueUnbound(HttpSessionBindingEvent event) {
		String sessionId = event.getSession().getId();
		String msg = "[LOGOUT] loginId:" + token.loginId + " userId:" + token.userId + " userName:" + token.userName + " userType:" + token.userType + " sessionid:" + sessionId + " caused by " + cause;

			authLogger.info(msg);
		cleanup(sessionId);
	}

	/**
	 * セッションに紐付いたアップロード用の一時ディレクトリを削除する
	 *
	 * @param tempDir
	 */
	private void cleanup(String sessionId) {
		if (workPath != null && workPath.contains(sessionId)) {
			try {
//				FileUtil.deleteDirectory(workPath);
				FileUtil.deleteDirectoryGracefully(new File(workPath));
			} catch (IOException e) {
				logger.warn("delete directory failed: " + workPath, e);
			}
		}
	}

}
