package jp.agentec.sinaburocast.common.interceptor;

import jp.agentec.sinaburocast.common.annotation.NullOk;

import org.aopalliance.intercept.MethodInvocation;
import org.apache.commons.lang.ArrayUtils;
import org.seasar.framework.aop.interceptors.AbstractInterceptor;
import org.seasar.framework.log.Logger;

/**
 * Argument Interceptorクラス<br>
 * 引数がnullの場合例外をスローする
 *
 * @author tsukada
 *
 */
public class ArgumentInterceptor extends AbstractInterceptor {
    private static final long serialVersionUID = -9197894563727449743L;
    private static final Logger logger = Logger.getLogger(TraceInterceptor.class);
    private static final Class[] wrapperClasses = new Class[]{Byte.class, Short.class, Integer.class, Long.class, Character.class, Float.class, Double.class, Boolean.class};

	public ArgumentInterceptor() {
	}

    @Override
    public Object invoke(final MethodInvocation invocation) throws Throwable {
    	NullOk nullOk = invocation.getMethod().getAnnotation(NullOk.class);

    	if (nullOk != null && nullOk.targetNo()[0] == -1 && nullOk.excludeNo()[0] == -1 || !isTargetPackage(getTargetClass(invocation).getName())) {
            return invocation.proceed();
    	}

        final Class[] argsType = invocation.getMethod().getParameterTypes();
        final Object[] argsVal = invocation.getArguments();
        if (argsVal != null && argsVal.length > 0) {
            for (int i = 0; i < argsVal.length; ++i) {
//            	System.out.println(argsType[i] + " : " + argsVal[i]);
            	if (!isWrapper(argsType[i])
            		|| argsVal[i] != null
            		|| (nullOk != null && ArrayUtils.contains(nullOk.targetNo(), i))
            		|| (nullOk != null && nullOk.excludeNo()[0] != -1 && !ArrayUtils.contains(nullOk.excludeNo(), i))
            		) {
            		continue;
            	}
            	throw new IllegalArgumentException("argument is null. method=" + getTargetClass(invocation).getSimpleName() + "#" + invocation.getMethod().getName() + " argumentNo=" + i);
            }
        }

        return invocation.proceed();

    }

	private boolean isTargetPackage(String className) {
		if (className.startsWith("jp.agentec.sinaburocast.service.admin.")
				|| className.startsWith("jp.agentec.sinaburocast.service.cm.")
				|| className.startsWith("jp.agentec.sinaburocast.service.job.")) {
			return true;
		}
		return false;
	}

	private static boolean isWrapper(Class clazz) {
		return ArrayUtils.contains(wrapperClasses, clazz);
	}

}
