package jp.agentec.sinaburocast.form.admin.setting;

import java.util.HashMap;

import jp.agentec.sinaburocast.common.util.PropertyUtil;

import org.seasar.framework.util.StringUtil;


/**
 * pagingForm
 *
 * @author choi-c
 *
 */
public class PagingForm {
	
	public static final String PAGE_PER_CNT = "pagePerCnt";
	public static final String TOTAL_CNT = "totalCnt";
	public static final String CUR_PAGE = "curPage";
	public static final String TOTAL_PAGE = "totalPage";
	public static final String OFF_SET = "offSet";
	public static final String FIRST_INDEX = "firstIndex";
	public static final String LAST_INDEX = "lastIndex";
	
	
	/**デフォルトページング種類*/
	public static final String PAGING = "paging";
	
	//各ページング情報 ※デフォルト設定
	public HashMap<String,HashMap<String,Integer>> pagingMap = null;
	
	
	public PagingForm(){
		pagingMap = pagingMapAdd(PAGING);
	}
	/** 現在のページ番号*/
	public Integer pageNo = 1; 
	
	/**ページ別表示数*/
	public Integer pagePerCnt = PropertyUtil.getInt("PAGE_PER_CNT") == 0 ? 20 : PropertyUtil.getInt("PAGE_PER_CNT");
	
	
	/**
	 * 
	 * @param key ページング処理ごとに追加
	 * @param integerArgs  totalCnt,pagePerCnt,curPage,totalPage
	 * @return
	 */
	public HashMap<String,HashMap<String,Integer>> pagingMapAdd(String key,Integer... integerArgs){
		if(pagingMap == null){
			pagingMap = new HashMap<String, HashMap<String,Integer>>();
		}
		HashMap<String,Integer> map = new HashMap<String, Integer>();
		
		for (int i = 0; i < integerArgs.length; i++) {
			switch (i){ 
			case 0://ページ別表示数。
				map.put(PAGE_PER_CNT , integerArgs[i]);
				break;
			case 1://totalCnt 総カウント
				map.put(TOTAL_CNT, integerArgs[i]);
				break;
			case 2://現在ページ
				map.put(CUR_PAGE, integerArgs[i]);
				break;
			case 3://総ページ数
				map.put(TOTAL_PAGE, integerArgs[i]);
				break;
			default:
				break;
			}
		}
		
		if(!map.containsKey(PAGE_PER_CNT)){
			map.put(PAGE_PER_CNT , pagePerCnt);
		}
		
		if(!map.containsKey(TOTAL_CNT)){
			map.put(TOTAL_CNT , new Integer(0));
		}
		
		if(!map.containsKey(CUR_PAGE)){
			map.put(CUR_PAGE , new Integer(0));
		}
		
		if(!map.containsKey(TOTAL_PAGE)){
			map.put(TOTAL_PAGE , new Integer(0));
		}
		
		if(!map.containsKey(TOTAL_PAGE)){
			map.put(TOTAL_PAGE , new Integer(0));
		}
		
		pagingMap.put(key,map);
		
		return pagingMap;
	}	
		
	
	/**
	 * ページング情報を設定する。
	 * @param key
	 * @param argCurPage     現在ページ
	 * @param argTotalCount トータルカウント
	 */
	public void setPaging(String key,Integer argCurPage,Long argTotalCountLong){
		
		
		HashMap<String,Integer> map = null;
		if(pagingMap.containsKey(key) ){
			map = pagingMap.get(key);
		}else{
			map = pagingMap.get(PAGING);
		}
		
		//前回使ったトータルカウントを使う
		Integer argTotalCount = Integer.parseInt(argTotalCountLong.toString());
		if(argTotalCount == null || argTotalCount.intValue() == 0){
			argTotalCount = map.get(TOTAL_CNT);
		}
		
		if(argCurPage == null || argCurPage < 1){
			argCurPage = 1;
		}
		
		Integer pagePerCnt = map.get(PAGE_PER_CNT);
		Integer totalCnt = argTotalCount;
		Integer curPage = argCurPage;
		Integer totalPage = map.get(TOTAL_PAGE);
		Integer offSet = 0;
		
		totalCnt = argTotalCount;
		
		 
		//開始位置
		offSet = (curPage * pagePerCnt) - pagePerCnt;
		 
     	//総ーページ数。
		totalPage = (int)Math.ceil(totalCnt/pagePerCnt.doubleValue()); 
		
		map.put(OFF_SET, offSet);
		map.put(TOTAL_PAGE, totalPage);
		map.put(TOTAL_CNT, totalCnt);
		map.put(CUR_PAGE, argCurPage);
		
		map.put(FIRST_INDEX, Math.min(offSet+1,totalCnt));
		map.put(LAST_INDEX, Math.min(offSet+pagePerCnt,totalCnt));
		
		
	}
	
	/**
	 * 開始番号を返す
	 * @param pageKey ページング種別
	 * @return
	 */
	public int getOffSet(String pageKey){
		if(StringUtil.isBlank(pageKey)){
			pageKey = PAGING;
		}
		return pagingMap.get(pageKey).get(OFF_SET); 
	}
	
	/**
	 * 各ページ表示数を返す。
	 * @param pageKey
	 * @return
	 */
	public int getLimit(String pageKey){
		if(StringUtil.isBlank(pageKey)){
			pageKey = PAGING;
		}
		return pagingMap.get(pageKey).get(PAGE_PER_CNT);
	}
	
	/**
	 * ページ別表示数を変更する。
	 * @param pageKey
	 * @param pagePerCnt
	 */
	public void setPagePerCnt(String pageKey,Integer pagePerCnt){
		if(StringUtil.isBlank(pageKey)){
			pageKey = PAGING;
		}
		pagingMap.get(pageKey).put(PAGE_PER_CNT,pagePerCnt);
		
	}
	
		
	
	

}
